Playground help is available for the general topics listed below. In
addition, if you pass info() a function/object from the playground,
it will attempt to display guidance on an appropriate topic. For
example, `info(uniform)`. Keep in mind you can also use Python's
built-in help to get usage documentation on any function, like
`help(uniform)`, though you should probably try `info` first.

General Topics
--------------
+ overview
+ actions
+ frps
+ frp-combinators
+ frp-factories
+ kinds
+ kind-combinators
+ kind-factories
+ statistics
+ statistics-builtins
+ statistic-combinators
+ statistic-factories
+ utilities

In addition, there are sub-topics for each of these topics. A
sub-topic name is formed by joining the topic name to the sub-topic
with `::`. For example, `kinds::factories::uniform` gives details on
the `uniform` factory. (You can also apply info to the `uniform`
function directly with the same effect.) Within each of the topics
there is a list of available sub-topics.



